<!--

-->
{% if not nav_item.children %}
<li {% if nav_item.active %}class="active"{% endif %}>
    <a href="{{ nav_item.url|url }}">{{ nav_item.title }}</a>
</li>
{% else %}
  <li>
    {{ nav_item.title }}
    <ul>
        {% for nav_item in nav_item.children %}
            {% include "nav.html" %}
        {% endfor %}
    </ul>
  </li>
{% endif %}
